@@ -7,6 +7,7 @@ use base 'DBIx::Class::Core';
 
 __PACKAGE__->table_class('DBIx::Class::ResultSource::View');
 
+# NOTE this query is in `git grep 'THREE PLACES'`
 __PACKAGE__->table('port_utilization');
 __PACKAGE__->result_source_instance->is_virtual(1);
 __PACKAGE__->result_source_instance->view_definition(<<ENDSQL
@@ -17,11 +18,23 @@ __PACKAGE__->result_source_instance->view_definition(<<ENDSQL
               ELSE 0 END) as ports_in_use,
      sum(CASE WHEN (dp.type != 'propVirtual' AND dp.up_admin != 'up') THEN 1
               ELSE 0 END) as ports_shutdown,
-     sum(CASE WHEN (dp.type != 'propVirtual' AND dp.up_admin = 'up' AND dp.up != 'up'
-                    AND ( age(now(), to_timestamp(extract(epoch from d.last_discover) - (d.uptime - dp.lastchange)/100)) > ?::interval  )) THEN 1
-              ELSE 0 END) as ports_free
-   FROM device d LEFT JOIN device_port dp
+     sum(CASE
+      WHEN ( dp.type != 'propVirtual' AND dp.up_admin = 'up' AND dp.up != 'up'
+             AND (age(now(), to_timestamp(extract(epoch from d.last_discover) - (d.uptime/100))) < ?::interval)
+             AND (last_node.time_last IS NULL OR (age(now(), last_node.time_last)) > ?::interval) )
+        THEN 1
+      WHEN ( dp.type != 'propVirtual' AND dp.up_admin = 'up' AND dp.up != 'up'
+             AND (age(now(), to_timestamp(extract(epoch from d.last_discover) - (d.uptime - dp.lastchange)/100)) > ?::interval) )
+        THEN 1
+      ELSE 0
+     END) as ports_free
+   FROM device d
+   LEFT JOIN device_port dp
      ON d.ip = dp.ip
+   LEFT JOIN
+     ( SELECT DISTINCT ON (switch, port) * FROM node
+         ORDER BY switch, port, time_last desc ) AS last_node
+     ON dp.port = last_node.port AND dp.ip = last_node.switch
    GROUP BY d.dns, d.ip
    ORDER BY d.dns, d.ip
 ENDSQL
