@@ -19,6 +19,10 @@ register_worker({ phase => 'check' }, sub {
   return Status->info("macsuck skipped: $device is not macsuckable")
     unless is_macsuckable_now($device);
 
+  # support for Hooks
+  vars->{'hook_data'} = { $device->get_columns };
+  delete vars->{'hook_data'}->{'snmp_comm'}; # for privacy
+
   return Status->done('Macsuck is able to run.');
 });
 
